<?php
if (!class_exists('CP_Base_List_Table')) {
	require_once('CP_Base_List_Table.php' );
};

class CP_Infiltration_Table extends CP_Base_List_Table {

	function __construct() {
		parent::__construct(array(
			'singular' => 'wp_list_text_link', //Singular label
			'plural' => 'table-infiltration-stats', //plural label, also this well be one of the table css class
			'screen' => 'edit-infiltrations',
			'ajax' => false //We won't support Ajax for this table
		));
	}

	function get_columns() {
		return $columns = array(
			'id' => __('S/N'),
			'name' => __('Infiltration Name'),
			'stats' => __('Quick Stats'),
			'actions' => __('Action tools'),
		);
	}

	public function get_sortable_columns() {
		return $sortable = array(
//			'id' => 'id',
//			'name' => 'name',
//			'post_url' => 'post_url'
		);
	}

	function prepare_items() {
		global $wpdb, $_wp_column_headers;
		$screen = get_current_screen();

		/* -- Preparing your query -- */
		$query = "SELECT * FROM " . $wpdb->prefix . "sp_infiltration";

		$orderby = !empty($_GET["orderby"]) ? mysql_real_escape_string($_GET["orderby"]) : 'id';
		$order = !empty($_GET["order"]) ? mysql_real_escape_string($_GET["order"]) : 'DESC';
		if (!empty($orderby) & !empty($order)) {
			$query.=' ORDER BY ' . $orderby . ' ' . $order;
		}

		$totalitems = $wpdb->query($query); //return the total number of affected rows
	
		$perpage = 5;
		
		$paged = !empty($_GET["paged"]) ? mysql_real_escape_string($_GET["paged"]) : '';

		if (empty($paged) || !is_numeric($paged) || $paged <= 0) {
			$paged = 1;
		}

		$totalpages = ceil($totalitems / $perpage);

		if (!empty($paged) && !empty($perpage)) {
			$offset = ($paged - 1) * $perpage;
			$query.=' LIMIT ' . (int) $offset . ',' . (int) $perpage;
		}


		$this->set_pagination_args(array(
			"total_items" => $totalitems,
			"total_pages" => $totalpages,
			"per_page" => $perpage,
		));


		/* -- Register the Columns -- */
		$columns = $this->get_columns();
		$_wp_column_headers[$screen->id] = $columns;

		/* -- Fetch the items -- */
		$this->items = $wpdb->get_results($query);
		$this->get_stats();
	}

	public function column_default($item, $column_name) {
		if('stats' == $column_name){
			$c_days = 0;
			if(isset($item->stats['date_complite'])){
				$datetime1 = mktime();
				$datetime2 = strtotime($item->stats['date_complite']);
				if($datetime2 > $datetime1){
					$c_days = floor(($datetime2 - $datetime1)/(24*60*60));
				}
			}
			
			$out = 	'<div class="quick-stats-block">
									<p class="si-color-gp">Infiltrated '.$item->stats['gp_complite'].' Google + Communities</p>
									<p>Campaign Is '.round(($item->stats['fb_complite'] + $item->stats['fb_u_complite'] + $item->stats['tw_complite'] + $item->stats['tm_complite'] + $item->stats['gp_complite'] + $item->stats['pn_complite'])*100/$item->stats['count_total']).' % Completed So far</p>
									<p>Expected completion in '.$c_days.' days time	</p>
								</div>';
			
			return $out;
		};
		
		if('actions' == $column_name){
			$out =  '<div class="si-at-block"> 
				<a class="si-at-controllers at-view" href="/wp-admin/admin.php?page=edit-infiltrations&action=history&id='.$item->id.'">View Infiltration History</a>
					<div class="align">
						<a class="si-at-controllers at-edit" href="/wp-admin/admin.php?page=edit-infiltrations&action=show_create&id='.$item->id.'">Edit</a>';
							
			if($item->pause){
				$out .= '<a class="si-at-controllers at-pause-start" href="/wp-admin/admin.php?page=edit-infiltrations&action=start&id='.$item->id.'">Start</a>';
			} else {
				$out .= '<a class="si-at-controllers at-pause" href="/wp-admin/admin.php?page=edit-infiltrations&action=pause&id='.$item->id.'">Pause</a>';
			};
		
			$out .=	'<div class="clear"></div>
						</div>
							<a class="si-at-controllers at-delete" href="/wp-admin/admin.php?page=edit-infiltrations&action=delete&id='.$item->id.'">Delete Infiltration</a>
						</div>'; 
			 return $out;
		};

		return $item->$column_name;
	}
	
	public function get_stats(){
		global $wpdb;

		$arr_inf_tw = $wpdb->get_results( "SELECT infiltrate_id, COUNT(*) 'count_complite'  FROM ".  $wpdb->prefix. "sp_cron_tasks WHERE soc_type='twitter' AND state='complite' GROUP BY infiltrate_id", OBJECT_K);

		$arr_inf_fb = $wpdb->get_results( "SELECT infiltrate_id, COUNT(*) 'count_complite' FROM ".  $wpdb->prefix. "sp_cron_tasks WHERE soc_type='facebook' AND state='complite' AND soc_account_id <> target GROUP BY infiltrate_id", OBJECT_K);

		$arr_inf_fb_u = $wpdb->get_results( "SELECT infiltrate_id, COUNT(*) 'count_complite' FROM ".  $wpdb->prefix. "sp_cron_tasks WHERE soc_type='facebook' AND state='complite' AND soc_account_id = target GROUP BY infiltrate_id", OBJECT_K);

		$arr_inf_tm = $wpdb->get_results( "SELECT infiltrate_id, COUNT(*) 'count_complite' FROM ".  $wpdb->prefix. "sp_cron_tasks WHERE soc_type='tumblr' AND state='complite' GROUP BY infiltrate_id", OBJECT_K);
	
		$arr_inf_gp = $wpdb->get_results( "SELECT infiltrate_id, COUNT(*) 'count_complite' FROM ".  $wpdb->prefix. "sp_cron_tasks WHERE soc_type='google' AND state='complite' GROUP BY infiltrate_id", OBJECT_K);
		
		$arr_inf_pn = $wpdb->get_results( "SELECT infiltrate_id, COUNT(*) 'count_complite' FROM ".  $wpdb->prefix. "sp_cron_tasks WHERE soc_type='pinterest' AND state='complite' GROUP BY infiltrate_id", OBJECT_K);

		$arr_inf_total = $wpdb->get_results( "SELECT infiltrate_id, MAX(time_start) 'date_complite', COUNT(*) 'count_total' FROM ".  $wpdb->prefix. "sp_cron_tasks GROUP BY infiltrate_id", OBJECT_K);
		
		foreach($this->items as $key=>$item){
			$this->items[$key]->stats['tw_complite'] = isset($arr_inf_tw[$item->id])?$arr_inf_tw[$item->id]->count_complite:0;
			$this->items[$key]->stats['fb_complite'] = isset($arr_inf_fb[$item->id])?$arr_inf_fb[$item->id]->count_complite:0;
			$this->items[$key]->stats['fb_u_complite'] = isset($arr_inf_fb_u[$item->id])?$arr_inf_fb_u[$item->id]->count_complite:0;
			$this->items[$key]->stats['tm_complite'] = isset($arr_inf_tm[$item->id])?$arr_inf_tm[$item->id]->count_complite:0;
			$this->items[$key]->stats['gp_complite'] = isset($arr_inf_gp[$item->id])?$arr_inf_gp[$item->id]->count_complite:0;
			$this->items[$key]->stats['pn_complite'] = isset($arr_inf_pn[$item->id])?$arr_inf_pn[$item->id]->count_complite:0;
			if(isset($arr_inf_total[$item->id])){
				$this->items[$key]->stats['date_complite'] = $arr_inf_total[$item->id]->date_complite;
				$this->items[$key]->stats['count_total'] = $arr_inf_total[$item->id]->count_total;
			}else{
				$this->items[$key]->stats['date_complite'] = '';
				$this->items[$key]->stats['count_total'] = 1;
			};
		}
		
	}
}
?>
